summaryrefslogtreecommitdiffstats
path: root/wp-includes/comment.php
diff options
context:
space:
mode:
Diffstat (limited to 'wp-includes/comment.php')
-rw-r--r--wp-includes/comment.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/wp-includes/comment.php b/wp-includes/comment.php
index cca3901..748dd61 100644
--- a/wp-includes/comment.php
+++ b/wp-includes/comment.php
@@ -557,10 +557,11 @@ function wp_set_comment_cookies( $comment, $user, $cookies_consent = true ) {
* Filters the lifetime of the comment cookie in seconds.
*
* @since 2.8.0
+ * @since 6.6.0 The default $seconds value changed from 30000000 to YEAR_IN_SECONDS.
*
* @param int $seconds Comment cookie lifetime. Default 30000000.
*/
- $comment_cookie_lifetime = time() + apply_filters( 'comment_cookie_lifetime', 30000000 );
+ $comment_cookie_lifetime = time() + apply_filters( 'comment_cookie_lifetime', YEAR_IN_SECONDS );
$secure = ( 'https' === parse_url( home_url(), PHP_URL_SCHEME ) );
@@ -557,10 +557,11 @@ function wp_set_comment_cookies( $comment, $user, $cookies_consent = true ) {
*
- * @param int $seconds Comment cookie lifetime. Default 30000000.
+ * @param int $seconds Comment cookie lifetime. Default YEAR_IN_SECONDS.
*/